/**
 * 
 */
package library;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

/**
 * @author fiinmani
 *
 */
public class SqlHandler {
	Connection connection;

	/*
	 * 
	 */
	public SqlHandler() {

	}

	/*
	 * 
	 */
	public void GetConnection() {
		
		try {
			Class.forName(Text.driver);
			connection = DriverManager.getConnection(Text.url, Text.username, Text.password);
		} catch (ClassNotFoundException e) {
			System.out.println("SQL Driver was not found. SQL is not installed?");
		} catch (SQLException e) {
			System.out.println("Could not open the connection. Database not found.");
		}
	}

	/*
	 * 
	 */
	public void CloseConnection() {
		if (connection != null) {
			try {
				connection.close();
			} catch (SQLException e) {
				System.out.println("Could not close the connection.");
			} 
		}
	}

	/*
	 * 
	 */
	public void CreateDatabase() {
		Statement statement = null;

		try {
			statement = connection.createStatement();
			statement.executeUpdate(Text.CREATE_DATABASE);
		} catch (SQLException e) {
			System.out.println("Could not create the database.");
		} finally {
			if (statement != null) {
				try {
					statement.executeUpdate(Text.CREATE_BOOK_TABLE);
					statement.executeUpdate(Text.CREATE_DVD_TABLE);
					statement.close();
				} catch (SQLException e) {
					System.out.println("Could not create the table or close the statement.");
				} 
			}
		}
	}

	/*
	 * 
	 */
	public void DeleteDatabase() {
		Statement statement = null;

		try {
			statement = connection.createStatement();
			statement.executeUpdate(Text.DELETE);
		} catch (Exception e) {
			System.out.println("Could not delete the database.");
			e.printStackTrace();
		} finally {
			if (statement != null) {
				try {
					statement.close();
				} catch (SQLException e) {
					System.out.println("Could not close the statement.");
				} 
			}
		}
	}

	/*
	 * 
	 */
	public Object[] GetLibrary() {

		Object[] library = { new Vector<Book>(), new Vector<Dvd>() };

		library[0] = GetBooks(Text.GET_BOOK+Text.ORDER_BOOK);
		library[1] = GetDvds(Text.GET_DVD+Text.ORDER_DVD);

		return library;
	}

	/*
	 * 
	 */
	public Vector<Book> GetBooks(String queryText) {
		Statement statement = null;
		ResultSet res = null;
		Vector<Book> dataVector = new Vector<Book>();
		
		try {
			statement = connection.createStatement();

			res = statement.executeQuery(queryText);

			while (res.next()) {

				dataVector.addElement(new Book(res.getString(1),
											   res.getString(2),
											   res.getString(3),
											   res.getInt(4),
											   res.getString(5),
											   res.getString(6),
											   res.getInt(7),
											   res.getString(8)));
	        }
			res.close();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			if (statement != null) {
				try {
					statement.close();
				} catch (SQLException e) {
				} // nothing we can do
			}
		}
		return dataVector;
	}

	/*
	 * 
	 */
	public Vector<Dvd> GetDvds(String queryText) {
		Statement statement = null;
		ResultSet res = null;
		Vector<Dvd> dataVector = new Vector<Dvd>();
		
		try {
			statement = connection.createStatement();

			res = statement.executeQuery(queryText);

			while (res.next()) {

				dataVector.addElement(new Dvd(res.getString(1),
											  res.getInt(2),
											  res.getString(3),
											  res.getString(4),
											  res.getString(5),
											  res.getString(6),
											  res.getString(7)));
	        }
			res.close();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			if (statement != null) {
				try {
					statement.close();
				} catch (SQLException e) {
				} // nothing we can do
			}
		}
		return dataVector;
	}

	/*
	 * 
	 */
	public boolean AddBook(Book book) {
		PreparedStatement statement = null;
		boolean returnValue = false;
		boolean addfail = false;
		
		try {
			statement  = connection.prepareStatement(Text.ADD_BOOK);
			statement.setString(1,book.surname);
			statement.setString(2,book.forename);
			statement.setString(3,book.bookname);
			statement.setInt(4,book.pubyear);
			statement.setString(5,book.isbn);
			statement.setString(6,book.orgname);
			statement.setInt(7,book.orgyear);
			statement.setString(8,book.other);
			statement.executeUpdate();
		} catch (Exception e) {
			e.printStackTrace();
			System.out.println("Could not add book to the database.");
			addfail = true;
		} finally {
			if (statement != null) {
				try {
					statement.close();
					if (addfail != true) {
						returnValue = true;
					}
				} catch (SQLException e) {
				} // nothing we can do
			}
		}
		return returnValue;
	}
	
	/*
	 * 
	 */
	public boolean AddDvd(Dvd dvd) {
		PreparedStatement statement = null;
		boolean returnValue = false;
		boolean addfail = false;
		
		try {
			statement  = connection.prepareStatement(Text.ADD_DVD);
			statement.setString(1,dvd.name);
			statement.setInt(2,dvd.year);
			statement.setString(3,dvd.orgname);
			statement.setString(4,dvd.barcode);
			statement.setString(5,dvd.director);
			statement.setString(6,dvd.music);
			statement.setString(7,dvd.other);
			statement.executeUpdate();
		} catch (Exception e) {
			e.printStackTrace();
			System.out.println("Could not add book to the database.");
			addfail = true;
		} finally {
			if (statement != null) {
				try {
					statement.close();
					if (addfail != true) {
						returnValue = true;
					}
				} catch (SQLException e) {
				} // nothing we can do
			}
		}
		return returnValue;
	}

	/*
	 * 
	 */
	public boolean RemoveBook(Book book) {
		PreparedStatement statement = null;
		boolean returnValue = false;
		boolean addfail = false;
		
		try {
			statement  = connection.prepareStatement(Text.REMOVE_BOOK);
			statement.setString(1,book.surname);
			statement.setString(2,book.forename);
			statement.setString(3,book.bookname);
			statement.setInt(4,book.pubyear);
			statement.setString(5,book.isbn);
			statement.setString(6,book.orgname);
			statement.setInt(7,book.orgyear);
			statement.setString(8,book.other);
			statement.executeUpdate();
		} catch (Exception e) {
			e.printStackTrace();
			System.out.println("Could not remove book from the database.");
			addfail = true;
		} finally {
			if (statement != null) {
				try {
					statement.close();
					if (addfail != true) {
						returnValue = true;
					}
				} catch (SQLException e) {
				} // nothing we can do
			}
		}
		return returnValue;
	}

	/*
	 * 
	 */
	public boolean RemoveDvd(Dvd dvd) {
		PreparedStatement statement = null;
		boolean returnValue = false;
		boolean addfail = false;
		
		try {
			statement  = connection.prepareStatement(Text.REMOVE_DVD);
			statement.setString(1,dvd.name);
			statement.setInt(2,dvd.year);
			statement.setString(3,dvd.orgname);
			statement.setString(4,dvd.barcode);
			statement.setString(5,dvd.director);
			statement.setString(6,dvd.music);
			statement.setString(7,dvd.other);
			statement.executeUpdate();
		} catch (Exception e) {
			e.printStackTrace();
			System.out.println("Could not remove dvd from the database.");
			addfail = true;
		} finally {
			if (statement != null) {
				try {
					statement.close();
					if (addfail != true) {
						returnValue = true;
					}
				} catch (SQLException e) {
				} // nothing we can do
			}
		}
		return returnValue;
	}

	/*
	 * 
	 */
	public boolean ModifyBook(Book book, Book orgbook) {
		PreparedStatement statement = null;
		boolean returnValue = false;
		boolean addfail = false;
		
		try {
			statement  = connection.prepareStatement(Text.UPDATE_BOOK);
			statement.setString(1,book.surname);
			statement.setString(2,book.forename);
			statement.setString(3,book.bookname);
			statement.setInt(4,book.pubyear);
			statement.setString(5,book.isbn);
			statement.setString(6,book.orgname);
			statement.setInt(7,book.orgyear);
			statement.setString(8,orgbook.other);
			statement.setString(9,orgbook.surname);
			statement.setString(10,orgbook.forename);
			statement.setString(11,orgbook.bookname);
			statement.setInt(12,orgbook.pubyear);
			statement.setString(13,orgbook.isbn);
			statement.setString(14,orgbook.orgname);
			statement.setInt(15,orgbook.orgyear);
			statement.setString(16,orgbook.other);
			statement.executeUpdate();
		} catch (Exception e) {
			e.printStackTrace();
			System.out.println("Could not update book to the database.");
			addfail = true;
		} finally {
			if (statement != null) {
				try {
					statement.close();
					if (addfail != true) {
						returnValue = true;
					}
				} catch (SQLException e) {
				} // nothing we can do
			}
		}
		return returnValue;
	}

}

